# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.2] - 2024-04-23

### Added

- web app using gradio

## [0.0.1] - 2024-01-26

- Initial release

[Unreleased]: https://github.com/stefantaubert/en-tts/compare/v0.0.2...HEAD
[0.0.2]: https://github.com/stefantaubert/en-tts/compare/v0.0.1...v0.0.2
[0.0.1]: https://github.com/stefantaubert/en-tts/releases/tag/v0.0.1
